@@ -3,11 +3,11 @@ import sys
 import logging
 
 from fintix_modelcurator.callback import FintixCallback
-from fintix_modelcurator.utils import get_model_save_path, upload_model
+from fintix_modelcurator.utils import get_model_save_path, upload_model, log
 from fintix_modelcurator.config import Config
 from fintix_modelcurator.const import *
 
-__all__ = ['FintixCallback', 'get_model_save_path', 'upload_model']
+__all__ = ['FintixCallback', 'get_model_save_path', 'upload_model', 'log']
 
 
 def __init_logging():
